# -*- coding: utf-8 -*-

from django.core import urlresolvers
from django.http import HttpResponseRedirect
from django.contrib.auth import login, authenticate
from django.contrib.auth.decorators import login_required
from django.template import RequestContext
from django.shortcuts import render_to_response
from accounts.models import UserProfile
from accounts.forms import UserEditForm, UserRegistrationForm


def register(request, template_name="registration/register.html"):
    if request.method == "POST":
        postdata = request.POST.copy()
        form = UserRegistrationForm(postdata)
        if form.is_valid():
            form.save()
            username = postdata.get("username", "")
            password = postdata.get("password1", "")
            new_user = authenticate(username=username,
                                    password=password)
            if new_user and new_user.is_active:
                login(request, new_user)
                up = None
                try:
                    up = new_user.get_profile()
                except UserProfile.DoesNotExist:
                    up = UserProfile(user=new_user)
                up.save()

                url = urlresolvers.reverse("account_profile")
                return HttpResponseRedirect(url)
    else:
        form = UserRegistrationForm()
    return render_to_response(template_name, locals(),
                              context_instance=RequestContext(request))


@login_required
def profile(request, template_name="registration/profile.html"):
    try:
        user_profile = request.user.get_profile()
    except UserProfile.DoesNotExist:
        user_profile = UserProfile(user=request.user)
        user_profile.save()

    if request.method == "POST":
        postdata = request.POST.copy()
        form = UserEditForm(postdata, instance=user_profile)
        if form.is_valid():
            form.save()
    else:
        form = UserEditForm(instance=user_profile)

    return render_to_response(template_name, locals(),
                              context_instance=RequestContext(request))

